#
# spec file for package rke2-selinux
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rke2_relabel_files() \
umask 0022; \
mkdir -p /etc/cni; \
mkdir -p /opt/cni; \
mkdir -p /var/lib/cni; \
mkdir -p /var/lib/kubelet; \
mkdir -p /var/lib/rancher/rke2/data; \
mkdir -p /var/run/flannel; \
umask 0027; \
mkdir -p /var/lib/kubelet/pods; \
mkdir -p /var/lib/rancher/rke2/agent; \
umask 0066; \
mkdir -p /var/run/k3s; \
umask 0077; \
mkdir -p /var/lib/rancher/rke2/agent/containerd/io.containerd.snapshotter.v1.overlayfs/snapshots; \
mkdir -p /var/lib/rancher/rke2/server; \
restorecon -R -i /etc/systemd/system/rke2*; \
restorecon -R -i /usr/lib/systemd/system/rke2*; \
restorecon -R /var/lib/cni; \
restorecon -R /opt/cni; \
restorecon -R /etc/cni; \
restorecon -R /var/lib/kubelet; \
restorecon -R /var/lib/rancher; \
restorecon -R /var/run/k3s; \
restorecon -R /var/run/flannel

%define selinux_policyver 20210716-3.1
%define container_policyver 2.164.2-1.1

Name:           rke2-selinux
Version:        0.20.stable.1
Release:        1.1
Summary:        SELinux policy module for rke2

Group:          System Environment/Base
License:        Apache-2.0
URL:            https://github.com/rancher/rke2-selinux
Source0:        %{name}-%{version}.tar.gz
Source1:        Makefile
Source2:        PACKAGING_README.md

BuildArch:      noarch
BuildRequires:  container-selinux >= %{container_policyver}
BuildRequires:  git-core
BuildRequires:  selinux-policy >= %{selinux_policyver}
BuildRequires:  selinux-policy-devel >= %{selinux_policyver}

Requires:       policycoreutils
Requires:       selinux-tools
Requires(post): selinux-policy-base >= %{selinux_policyver}
Requires(post): policycoreutils
Requires(post): container-selinux >= %{container_policyver}
Requires(postun): policycoreutils

Provides:       %{name} = %{version}-%{release}
Obsoletes:      rke2-selinux < 0.9
Conflicts:      k3s-selinux

%description
This package installs and sets up the SELinux policy security module for rke2.

%prep
%autosetup

%build
cd policy/microos
make -f /usr/share/selinux/devel/Makefile rke2.pp

%install
install -d %{buildroot}%{_datadir}/selinux/packages
install -m 644 policy/microos/rke2.pp %{buildroot}%{_datadir}/selinux/packages
install -d %{buildroot}%{_datadir}/selinux/devel/include/contrib
install -m 644 policy/microos/rke2.if %{buildroot}%{_datadir}/selinux/devel/include/contrib/
install -d %{buildroot}/etc/selinux/targeted/contexts/users/

%pre
%selinux_relabel_pre

%post
semodule -n -i %{_datadir}/selinux/packages/rke2.pp
if /usr/sbin/selinuxenabled ; then
    /usr/sbin/load_policy
    %rke2_relabel_files
fi;

%postun
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall rke2
fi;

%posttrans
%selinux_relabel_post

%files
%attr(0600,root,root) %{_datadir}/selinux/packages/rke2.pp
%{_datadir}/selinux/devel/include/contrib/rke2.if

%changelog
* Tue Jun 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.20.stable.1:
  * Fix directory permissions in rpm postinstall script
* Sun Jun 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add Makefile to make updating the hardcoded versions easier
* Wed Jun 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.19.stable.1:
  * Build sle micro images on sle micro
  * Use restrictive umask when creating directories
  * Fix logs context (#82)
  * Remove region
  * fix: CI changes and script changes for rpms
  * feat: add new rpm tool for handling repo sign and upload
  * feat: add selinux write and connectto to kine sock
  * Fix gpg key secret again
  * Fix gpg key secret
  * More fixes to vault secrets paths (#73)
  * Fix vault secrets paths (#72)
  * GHA Migration (#71)
* Thu May  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.18.stable.2:
  * bugfix: Adjust Microos TLS policy regex by @dennislapchenko in
    [#63]
  * build: Align drone base images by @pjbgf in #60
  * Add /etc/cni to the rke2-selinux context by @galal-hussein in
    [#67]
* Sat Dec  9 2023 kastl@b1-systems.de
- Update to version 0.17.stable.1:
  * Revert to files_type instead of container_file_type for EL8
    (#61)
* Tue Oct 31 2023 kastl@b1-systems.de
- Update to version 0.16.stable.1:
  * Fix container_unit_file_t for rke2 unit file (#57)
* Thu Oct  5 2023 kastl@b1-systems.de
- Update to version 0.15.stable.1:
  * revert to files_type instead of container_file_type for
    slemicro (#54)
  * rke2_tls_t type for cert files (#53)
  * Adding support for /opt/rke2/bin/rke2 and fixing rke2_service_t
    watch on container_var_lib_t (#48)
  * Allow rke2_service_t to watch cert files in RHEL9 (#49)
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.14.stable.1:
  * Add DAC_OVERRIDE cap to iscsid_t (#45)
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.13.stable.1:
  * Remove snapshot filetranspatterns for all policies (#44)
* Wed May 31 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.12.stable.1:
  * Update el8 container-selinux (#42)
  * use slemicro for dist name in slemicro policy (#41)
  * Add slemicro distro (#40)
  * Update the container-selinux requirement (#38)
  * Fix EOF error
  * Add container_file_t context to /opt/cni
  * Bump pip/setuptools version; switch to https for git clone
  * Use SHA256 to sign packages instead of default SHA1
  * centos 8 vault: side-step eol problems (#28)
  * sle: support for sle-micro (#23)
  * Add max version tp el8 (#39)
  * Update the container-selinux requirement (#38)
  * Add EL9 to the policy (#37)
  * Fix container_domain_template() calls (#35)
* Thu Nov 24 2022 kastl@b1-systems.de
- Update to version 0.11.latest.1:
  * Fix EOF error
  * Add container_file_t context to /opt/cni
  * Bump pip/setuptools version; switch to https for git clone
  * Use SHA256 to sign packages instead of default SHA1
  * centos 8 vault: side-step eol problems (#28)
* Wed Jan 26 2022 Richard Brown <rbrown@suse.com>
- Add missing specfile license/copyright
* Sun Jan  9 2022 Johannes Kastl <kastl@b1-systems.de>
- create new package rke2-selinux at version 0.9.latest.1
